/*
    cssh - cluster secure shell
    Copyright (C) 2015-2021  Andreas Baumann

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#include "port.h"

#include <time.h>

void cssh_msleep( unsigned int msec )
{
	struct timespec ts;
	ts.tv_sec = msec / 1000;
	ts.tv_nsec = ( msec % 1000 ) * 1000000;
	nanosleep( &ts, NULL );
}
